"""
## AWS::MediaConvert Construct Library

<!--BEGIN STABILITY BANNER-->---


![cfn-resources: Stable](https://img.shields.io/badge/cfn--resources-stable-success.svg?style=for-the-badge)

> All classes with the `Cfn` prefix in this module ([CFN Resources](https://docs.aws.amazon.com/cdk/latest/guide/constructs.html#constructs_lib)) are always stable and safe to use.

---
<!--END STABILITY BANNER-->

This module is part of the [AWS Cloud Development Kit](https://github.com/aws/aws-cdk) project.

```python
# Example automatically generated. See https://github.com/aws/jsii/issues/826
import aws_cdk.aws_mediaconvert as mediaconvert
```
"""
import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

import aws_cdk.core
import constructs

__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-mediaconvert", "1.33.1", __name__, "aws-mediaconvert@1.33.1.jsii.tgz")


@jsii.implements(aws_cdk.core.IInspectable)
class CfnJobTemplate(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-mediaconvert.CfnJobTemplate"):
    """A CloudFormation ``AWS::MediaConvert::JobTemplate``.

    see
    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html
    cloudformationResource:
    :cloudformationResource:: AWS::MediaConvert::JobTemplate
    """
    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, settings_json: typing.Any, acceleration_settings: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["AccelerationSettingsProperty"]]]=None, category: typing.Optional[str]=None, description: typing.Optional[str]=None, name: typing.Optional[str]=None, priority: typing.Optional[jsii.Number]=None, queue: typing.Optional[str]=None, status_update_interval: typing.Optional[str]=None, tags: typing.Any=None) -> None:
        """Create a new ``AWS::MediaConvert::JobTemplate``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param settings_json: ``AWS::MediaConvert::JobTemplate.SettingsJson``.
        :param acceleration_settings: ``AWS::MediaConvert::JobTemplate.AccelerationSettings``.
        :param category: ``AWS::MediaConvert::JobTemplate.Category``.
        :param description: ``AWS::MediaConvert::JobTemplate.Description``.
        :param name: ``AWS::MediaConvert::JobTemplate.Name``.
        :param priority: ``AWS::MediaConvert::JobTemplate.Priority``.
        :param queue: ``AWS::MediaConvert::JobTemplate.Queue``.
        :param status_update_interval: ``AWS::MediaConvert::JobTemplate.StatusUpdateInterval``.
        :param tags: ``AWS::MediaConvert::JobTemplate.Tags``.
        """
        props = CfnJobTemplateProps(settings_json=settings_json, acceleration_settings=acceleration_settings, category=category, description=description, name=name, priority=priority, queue=queue, status_update_interval=status_update_interval, tags=tags)

        jsii.create(CfnJobTemplate, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
        """Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "inspect", [inspector])

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
        """
        :param props: -
        """
        return jsii.invoke(self, "renderProperties", [props])

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
        """The CloudFormation resource type name for this resource class."""
        return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> str:
        """
        cloudformationAttribute:
        :cloudformationAttribute:: Arn
        """
        return jsii.get(self, "attrArn")

    @builtins.property
    @jsii.member(jsii_name="attrName")
    def attr_name(self) -> str:
        """
        cloudformationAttribute:
        :cloudformationAttribute:: Name
        """
        return jsii.get(self, "attrName")

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
        return jsii.get(self, "cfnProperties")

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> aws_cdk.core.TagManager:
        """``AWS::MediaConvert::JobTemplate.Tags``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-tags
        """
        return jsii.get(self, "tags")

    @builtins.property
    @jsii.member(jsii_name="settingsJson")
    def settings_json(self) -> typing.Any:
        """``AWS::MediaConvert::JobTemplate.SettingsJson``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-settingsjson
        """
        return jsii.get(self, "settingsJson")

    @settings_json.setter
    def settings_json(self, value: typing.Any):
        jsii.set(self, "settingsJson", value)

    @builtins.property
    @jsii.member(jsii_name="accelerationSettings")
    def acceleration_settings(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["AccelerationSettingsProperty"]]]:
        """``AWS::MediaConvert::JobTemplate.AccelerationSettings``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-accelerationsettings
        """
        return jsii.get(self, "accelerationSettings")

    @acceleration_settings.setter
    def acceleration_settings(self, value: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["AccelerationSettingsProperty"]]]):
        jsii.set(self, "accelerationSettings", value)

    @builtins.property
    @jsii.member(jsii_name="category")
    def category(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::JobTemplate.Category``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-category
        """
        return jsii.get(self, "category")

    @category.setter
    def category(self, value: typing.Optional[str]):
        jsii.set(self, "category", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::JobTemplate.Description``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-description
        """
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]):
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::JobTemplate.Name``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-name
        """
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]):
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="priority")
    def priority(self) -> typing.Optional[jsii.Number]:
        """``AWS::MediaConvert::JobTemplate.Priority``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-priority
        """
        return jsii.get(self, "priority")

    @priority.setter
    def priority(self, value: typing.Optional[jsii.Number]):
        jsii.set(self, "priority", value)

    @builtins.property
    @jsii.member(jsii_name="queue")
    def queue(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::JobTemplate.Queue``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-queue
        """
        return jsii.get(self, "queue")

    @queue.setter
    def queue(self, value: typing.Optional[str]):
        jsii.set(self, "queue", value)

    @builtins.property
    @jsii.member(jsii_name="statusUpdateInterval")
    def status_update_interval(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::JobTemplate.StatusUpdateInterval``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-statusupdateinterval
        """
        return jsii.get(self, "statusUpdateInterval")

    @status_update_interval.setter
    def status_update_interval(self, value: typing.Optional[str]):
        jsii.set(self, "statusUpdateInterval", value)

    @jsii.data_type(jsii_type="@aws-cdk/aws-mediaconvert.CfnJobTemplate.AccelerationSettingsProperty", jsii_struct_bases=[], name_mapping={'mode': 'mode'})
    class AccelerationSettingsProperty():
        def __init__(self, *, mode: str):
            """
            :param mode: ``CfnJobTemplate.AccelerationSettingsProperty.Mode``.

            see
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-accelerationsettings.html
            """
            self._values = {
                'mode': mode,
            }

        @builtins.property
        def mode(self) -> str:
            """``CfnJobTemplate.AccelerationSettingsProperty.Mode``.

            see
            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediaconvert-jobtemplate-accelerationsettings.html#cfn-mediaconvert-jobtemplate-accelerationsettings-mode
            """
            return self._values.get('mode')

        def __eq__(self, rhs) -> bool:
            return isinstance(rhs, self.__class__) and rhs._values == self._values

        def __ne__(self, rhs) -> bool:
            return not (rhs == self)

        def __repr__(self) -> str:
            return 'AccelerationSettingsProperty(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())



@jsii.data_type(jsii_type="@aws-cdk/aws-mediaconvert.CfnJobTemplateProps", jsii_struct_bases=[], name_mapping={'settings_json': 'settingsJson', 'acceleration_settings': 'accelerationSettings', 'category': 'category', 'description': 'description', 'name': 'name', 'priority': 'priority', 'queue': 'queue', 'status_update_interval': 'statusUpdateInterval', 'tags': 'tags'})
class CfnJobTemplateProps():
    def __init__(self, *, settings_json: typing.Any, acceleration_settings: typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnJobTemplate.AccelerationSettingsProperty"]]]=None, category: typing.Optional[str]=None, description: typing.Optional[str]=None, name: typing.Optional[str]=None, priority: typing.Optional[jsii.Number]=None, queue: typing.Optional[str]=None, status_update_interval: typing.Optional[str]=None, tags: typing.Any=None):
        """Properties for defining a ``AWS::MediaConvert::JobTemplate``.

        :param settings_json: ``AWS::MediaConvert::JobTemplate.SettingsJson``.
        :param acceleration_settings: ``AWS::MediaConvert::JobTemplate.AccelerationSettings``.
        :param category: ``AWS::MediaConvert::JobTemplate.Category``.
        :param description: ``AWS::MediaConvert::JobTemplate.Description``.
        :param name: ``AWS::MediaConvert::JobTemplate.Name``.
        :param priority: ``AWS::MediaConvert::JobTemplate.Priority``.
        :param queue: ``AWS::MediaConvert::JobTemplate.Queue``.
        :param status_update_interval: ``AWS::MediaConvert::JobTemplate.StatusUpdateInterval``.
        :param tags: ``AWS::MediaConvert::JobTemplate.Tags``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html
        """
        self._values = {
            'settings_json': settings_json,
        }
        if acceleration_settings is not None: self._values["acceleration_settings"] = acceleration_settings
        if category is not None: self._values["category"] = category
        if description is not None: self._values["description"] = description
        if name is not None: self._values["name"] = name
        if priority is not None: self._values["priority"] = priority
        if queue is not None: self._values["queue"] = queue
        if status_update_interval is not None: self._values["status_update_interval"] = status_update_interval
        if tags is not None: self._values["tags"] = tags

    @builtins.property
    def settings_json(self) -> typing.Any:
        """``AWS::MediaConvert::JobTemplate.SettingsJson``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-settingsjson
        """
        return self._values.get('settings_json')

    @builtins.property
    def acceleration_settings(self) -> typing.Optional[typing.Union[typing.Optional[aws_cdk.core.IResolvable], typing.Optional["CfnJobTemplate.AccelerationSettingsProperty"]]]:
        """``AWS::MediaConvert::JobTemplate.AccelerationSettings``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-accelerationsettings
        """
        return self._values.get('acceleration_settings')

    @builtins.property
    def category(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::JobTemplate.Category``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-category
        """
        return self._values.get('category')

    @builtins.property
    def description(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::JobTemplate.Description``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-description
        """
        return self._values.get('description')

    @builtins.property
    def name(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::JobTemplate.Name``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-name
        """
        return self._values.get('name')

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        """``AWS::MediaConvert::JobTemplate.Priority``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-priority
        """
        return self._values.get('priority')

    @builtins.property
    def queue(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::JobTemplate.Queue``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-queue
        """
        return self._values.get('queue')

    @builtins.property
    def status_update_interval(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::JobTemplate.StatusUpdateInterval``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-statusupdateinterval
        """
        return self._values.get('status_update_interval')

    @builtins.property
    def tags(self) -> typing.Any:
        """``AWS::MediaConvert::JobTemplate.Tags``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-jobtemplate.html#cfn-mediaconvert-jobtemplate-tags
        """
        return self._values.get('tags')

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return 'CfnJobTemplateProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())


@jsii.implements(aws_cdk.core.IInspectable)
class CfnPreset(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-mediaconvert.CfnPreset"):
    """A CloudFormation ``AWS::MediaConvert::Preset``.

    see
    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html
    cloudformationResource:
    :cloudformationResource:: AWS::MediaConvert::Preset
    """
    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, settings_json: typing.Any, category: typing.Optional[str]=None, description: typing.Optional[str]=None, name: typing.Optional[str]=None, tags: typing.Any=None) -> None:
        """Create a new ``AWS::MediaConvert::Preset``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param settings_json: ``AWS::MediaConvert::Preset.SettingsJson``.
        :param category: ``AWS::MediaConvert::Preset.Category``.
        :param description: ``AWS::MediaConvert::Preset.Description``.
        :param name: ``AWS::MediaConvert::Preset.Name``.
        :param tags: ``AWS::MediaConvert::Preset.Tags``.
        """
        props = CfnPresetProps(settings_json=settings_json, category=category, description=description, name=name, tags=tags)

        jsii.create(CfnPreset, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
        """Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "inspect", [inspector])

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
        """
        :param props: -
        """
        return jsii.invoke(self, "renderProperties", [props])

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
        """The CloudFormation resource type name for this resource class."""
        return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> str:
        """
        cloudformationAttribute:
        :cloudformationAttribute:: Arn
        """
        return jsii.get(self, "attrArn")

    @builtins.property
    @jsii.member(jsii_name="attrName")
    def attr_name(self) -> str:
        """
        cloudformationAttribute:
        :cloudformationAttribute:: Name
        """
        return jsii.get(self, "attrName")

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
        return jsii.get(self, "cfnProperties")

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> aws_cdk.core.TagManager:
        """``AWS::MediaConvert::Preset.Tags``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-tags
        """
        return jsii.get(self, "tags")

    @builtins.property
    @jsii.member(jsii_name="settingsJson")
    def settings_json(self) -> typing.Any:
        """``AWS::MediaConvert::Preset.SettingsJson``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-settingsjson
        """
        return jsii.get(self, "settingsJson")

    @settings_json.setter
    def settings_json(self, value: typing.Any):
        jsii.set(self, "settingsJson", value)

    @builtins.property
    @jsii.member(jsii_name="category")
    def category(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Preset.Category``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-category
        """
        return jsii.get(self, "category")

    @category.setter
    def category(self, value: typing.Optional[str]):
        jsii.set(self, "category", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Preset.Description``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-description
        """
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]):
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Preset.Name``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-name
        """
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]):
        jsii.set(self, "name", value)


@jsii.data_type(jsii_type="@aws-cdk/aws-mediaconvert.CfnPresetProps", jsii_struct_bases=[], name_mapping={'settings_json': 'settingsJson', 'category': 'category', 'description': 'description', 'name': 'name', 'tags': 'tags'})
class CfnPresetProps():
    def __init__(self, *, settings_json: typing.Any, category: typing.Optional[str]=None, description: typing.Optional[str]=None, name: typing.Optional[str]=None, tags: typing.Any=None):
        """Properties for defining a ``AWS::MediaConvert::Preset``.

        :param settings_json: ``AWS::MediaConvert::Preset.SettingsJson``.
        :param category: ``AWS::MediaConvert::Preset.Category``.
        :param description: ``AWS::MediaConvert::Preset.Description``.
        :param name: ``AWS::MediaConvert::Preset.Name``.
        :param tags: ``AWS::MediaConvert::Preset.Tags``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html
        """
        self._values = {
            'settings_json': settings_json,
        }
        if category is not None: self._values["category"] = category
        if description is not None: self._values["description"] = description
        if name is not None: self._values["name"] = name
        if tags is not None: self._values["tags"] = tags

    @builtins.property
    def settings_json(self) -> typing.Any:
        """``AWS::MediaConvert::Preset.SettingsJson``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-settingsjson
        """
        return self._values.get('settings_json')

    @builtins.property
    def category(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Preset.Category``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-category
        """
        return self._values.get('category')

    @builtins.property
    def description(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Preset.Description``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-description
        """
        return self._values.get('description')

    @builtins.property
    def name(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Preset.Name``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-name
        """
        return self._values.get('name')

    @builtins.property
    def tags(self) -> typing.Any:
        """``AWS::MediaConvert::Preset.Tags``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-preset.html#cfn-mediaconvert-preset-tags
        """
        return self._values.get('tags')

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return 'CfnPresetProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())


@jsii.implements(aws_cdk.core.IInspectable)
class CfnQueue(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-mediaconvert.CfnQueue"):
    """A CloudFormation ``AWS::MediaConvert::Queue``.

    see
    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html
    cloudformationResource:
    :cloudformationResource:: AWS::MediaConvert::Queue
    """
    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, description: typing.Optional[str]=None, name: typing.Optional[str]=None, pricing_plan: typing.Optional[str]=None, status: typing.Optional[str]=None, tags: typing.Any=None) -> None:
        """Create a new ``AWS::MediaConvert::Queue``.

        :param scope: - scope in which this resource is defined.
        :param id: - scoped id of the resource.
        :param description: ``AWS::MediaConvert::Queue.Description``.
        :param name: ``AWS::MediaConvert::Queue.Name``.
        :param pricing_plan: ``AWS::MediaConvert::Queue.PricingPlan``.
        :param status: ``AWS::MediaConvert::Queue.Status``.
        :param tags: ``AWS::MediaConvert::Queue.Tags``.
        """
        props = CfnQueueProps(description=description, name=name, pricing_plan=pricing_plan, status=status, tags=tags)

        jsii.create(CfnQueue, self, [scope, id, props])

    @jsii.member(jsii_name="inspect")
    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
        """Examines the CloudFormation resource and discloses attributes.

        :param inspector: - tree inspector to collect and process attributes.

        stability
        :stability: experimental
        """
        return jsii.invoke(self, "inspect", [inspector])

    @jsii.member(jsii_name="renderProperties")
    def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
        """
        :param props: -
        """
        return jsii.invoke(self, "renderProperties", [props])

    @jsii.python.classproperty
    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
    def CFN_RESOURCE_TYPE_NAME(cls) -> str:
        """The CloudFormation resource type name for this resource class."""
        return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")

    @builtins.property
    @jsii.member(jsii_name="attrArn")
    def attr_arn(self) -> str:
        """
        cloudformationAttribute:
        :cloudformationAttribute:: Arn
        """
        return jsii.get(self, "attrArn")

    @builtins.property
    @jsii.member(jsii_name="attrName")
    def attr_name(self) -> str:
        """
        cloudformationAttribute:
        :cloudformationAttribute:: Name
        """
        return jsii.get(self, "attrName")

    @builtins.property
    @jsii.member(jsii_name="cfnProperties")
    def _cfn_properties(self) -> typing.Mapping[str,typing.Any]:
        return jsii.get(self, "cfnProperties")

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> aws_cdk.core.TagManager:
        """``AWS::MediaConvert::Queue.Tags``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-tags
        """
        return jsii.get(self, "tags")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Queue.Description``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-description
        """
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]):
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Queue.Name``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-name
        """
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]):
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="pricingPlan")
    def pricing_plan(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Queue.PricingPlan``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-pricingplan
        """
        return jsii.get(self, "pricingPlan")

    @pricing_plan.setter
    def pricing_plan(self, value: typing.Optional[str]):
        jsii.set(self, "pricingPlan", value)

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Queue.Status``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-status
        """
        return jsii.get(self, "status")

    @status.setter
    def status(self, value: typing.Optional[str]):
        jsii.set(self, "status", value)


@jsii.data_type(jsii_type="@aws-cdk/aws-mediaconvert.CfnQueueProps", jsii_struct_bases=[], name_mapping={'description': 'description', 'name': 'name', 'pricing_plan': 'pricingPlan', 'status': 'status', 'tags': 'tags'})
class CfnQueueProps():
    def __init__(self, *, description: typing.Optional[str]=None, name: typing.Optional[str]=None, pricing_plan: typing.Optional[str]=None, status: typing.Optional[str]=None, tags: typing.Any=None):
        """Properties for defining a ``AWS::MediaConvert::Queue``.

        :param description: ``AWS::MediaConvert::Queue.Description``.
        :param name: ``AWS::MediaConvert::Queue.Name``.
        :param pricing_plan: ``AWS::MediaConvert::Queue.PricingPlan``.
        :param status: ``AWS::MediaConvert::Queue.Status``.
        :param tags: ``AWS::MediaConvert::Queue.Tags``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html
        """
        self._values = {
        }
        if description is not None: self._values["description"] = description
        if name is not None: self._values["name"] = name
        if pricing_plan is not None: self._values["pricing_plan"] = pricing_plan
        if status is not None: self._values["status"] = status
        if tags is not None: self._values["tags"] = tags

    @builtins.property
    def description(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Queue.Description``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-description
        """
        return self._values.get('description')

    @builtins.property
    def name(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Queue.Name``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-name
        """
        return self._values.get('name')

    @builtins.property
    def pricing_plan(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Queue.PricingPlan``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-pricingplan
        """
        return self._values.get('pricing_plan')

    @builtins.property
    def status(self) -> typing.Optional[str]:
        """``AWS::MediaConvert::Queue.Status``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-status
        """
        return self._values.get('status')

    @builtins.property
    def tags(self) -> typing.Any:
        """``AWS::MediaConvert::Queue.Tags``.

        see
        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediaconvert-queue.html#cfn-mediaconvert-queue-tags
        """
        return self._values.get('tags')

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return 'CfnQueueProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())


__all__ = ["CfnJobTemplate", "CfnJobTemplateProps", "CfnPreset", "CfnPresetProps", "CfnQueue", "CfnQueueProps", "__jsii_assembly__"]

publication.publish()
